package com.yiqi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.system.domain.SysDataGroup;
import com.yiqi.system.service.ISysDataGroupService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 组合数据Controller
 *
 * @author douya
 * @date 2024-10-29
 */
@Api(tags = "管理后台 - 组合数据")
@RestController
@RequestMapping(UrlConstants.managerApi + "/system/group")
public class SysDataGroupController extends BaseController {
    @Autowired
    private ISysDataGroupService sysDataGroupService;


    //<editor-folder desc="基础函数">
/**
 * 查询组合数据列表
 */
@PreAuthorize("@ss.hasPermi('system:group:list')")
@GetMapping("/list")
    @ApiOperation(value = "查询组合数据列表")
    public TableDataInfo list(SysDataGroup sysDataGroup) {
        startPage();
        List<SysDataGroup> list = sysDataGroupService.selectSysDataGroupList(sysDataGroup);
        return getDataTable(list);
    }

    /**
     * 导出组合数据列表
     */
    @PreAuthorize("@ss.hasPermi('system:group:export')")
    @Log(title = "组合数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出组合数据列表")
    public void export(HttpServletResponse response, SysDataGroup sysDataGroup) {
        List<SysDataGroup> list = sysDataGroupService.selectSysDataGroupList(sysDataGroup);
        ExcelUtil<SysDataGroup> util = new ExcelUtil<SysDataGroup>(SysDataGroup. class);
        util.exportExcel(response, list, "组合数据数据");
    }

    /**
     * 获取组合数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:group:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取组合数据详细信息")
    public AjaxResult getInfo(@PathVariable("id") Integer id) {
        return success(sysDataGroupService.selectSysDataGroupById(id));
    }

    /**
     * 新增组合数据
     */
    @PreAuthorize("@ss.hasPermi('system:group:add')")
    @Log(title = "组合数据", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增组合数据")
    public AjaxResult add(@RequestBody SysDataGroup sysDataGroup) {
        sysDataGroup.setCreateById(getUserId());
        sysDataGroup.setCreateBy(getUsername());
        return toAjax(sysDataGroupService.insertSysDataGroup(sysDataGroup));
    }

    /**
     * 修改组合数据
     */
    @PreAuthorize("@ss.hasPermi('system:group:edit')")
    @Log(title = "组合数据", businessType = BusinessType.UPDATE)
    @PostMapping(value = "/{id}")
    @ApiOperation(value = "修改组合数据")
    public AjaxResult edit(@RequestBody SysDataGroup sysDataGroup) {
        sysDataGroup.setUpdateById(getUserId());
        sysDataGroup.setUpdateBy(getUsername());
        return toAjax(sysDataGroupService.updateSysDataGroup(sysDataGroup));
    }

    /**
     * 删除组合数据
     */
    @PreAuthorize("@ss.hasPermi('system:group:remove')")
    @Log(title = "组合数据", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除组合数据")
    public AjaxResult remove(@PathVariable Integer[] ids) {
        return toAjax(sysDataGroupService.deleteSysDataGroupByIds(ids));
    }


    //</editor-folder>
}
